cointrader.strategies package
=============================

Submodules
----------

cointrader.strategies.trend module
----------------------------------

.. automodule:: cointrader.strategies.trend
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cointrader.strategies
    :members:
    :undoc-members:
    :show-inheritance:
